diff doc/interpreter/genpropdoc.m @ 24423:1d52db450db4

Change ishandle to return true for Java objects for Matlab compatibility. Add new function isgraphics() for Matlab compatibility. Change over existing instances of ishandle to ishghandle. * NEWS: Announce changes. * scripts/plot/util/isgraphics.m: New function. * scripts/plot/util/ishandle.m: New function. * scripts/plot/util/module.mk: Add isgraphics.m and ishandle.m to build system. * plot.txi: Change documentation around ishandle. Add isgraphics DOCSTRING to manual. * graphics.cc (Fishghandle): Rename function from ishandle to ishghandle. Add seealso links in docstring. * graphics.cc: Rename all instances of is_handle to is_hghandle. * genpropdoc.m, voronoi.m, guidata.m, guihandles.m, __uiobject_split_args__.m, uibuttongroup.m, uicontrol.m, uiwait.m, waitbar.m, brighten.m, delete.m, getappdata.m, isappdata.m, rmappdata.m, setappdata.m, __clabel__.m, camlookat.m, clabel.m, legend.m, material.m, thetaticks.m, whitebg.m, camlight.m, colorbar.m, isocolors.m, isonormals.m, plotmatrix.m, plotyy.m, reducepatch.m, shrinkfaces.m, __actual_axis_position__.m, __opengl_info__.m, __plt_get_axis_arg__.m, ancestor.m, copyobj.m, findobj.m, hdl2struct.m, hgsave.m, hold.m, isaxes.m, isfigure.m, ishold.m, isprop.m, linkprop.m, newplot.m, print.m, __gnuplot_draw_axes__.m, __gnuplot_draw_figure__.m, rotate.m, saveas.m, struct2hdl.m, subplot.m: Replace instances of ishandle with ishghandle in existing code.
author Rik <rik@octave.org>
date Sun, 17 Dec 2017 07:04:31 -0800
parents 730227072acb
children 8ff3c13d14c1
line wrap: on
line diff
--- a/doc/interpreter/genpropdoc.m	Sat Dec 16 18:41:41 2017 -0800
+++ b/doc/interpreter/genpropdoc.m	Sun Dec 17 07:04:31 2017 -0800
@@ -1635,7 +1635,7 @@
 function s = getstructure (objname, base = [])
   hf = [];
   if (! strcmp (objname, "root"))
     ## Use an improbable number to avoid ishandle to return true for 1
     hf = figure (2265465, "visible", "off");
   endif
 
@@ -1705,7 +1705,7 @@
   def = get (h, field);
 
   ## Don't print default values for graphics handles
-  if (isscalar (def) && def != 0 && ishandle (def))
+  if (isscalar (def) && def != 0 && ishghandle (def))
     def = "";
   else
     if (ischar (def))
@@ -1635,7 +1635,7 @@
   hf = [];
   if (! strcmp (objname, "root"))
-    ## Use an improbable number to avoid ishandle to return true for 1
+    ## Use an improbable number to avoid ishghandle to return true for 1
     hf = figure (2265465, "visible", "off");
   endif